@@ -104,11 +104,10 @@ manifest_schema = {
                             "read": {"type": "array", "items": {"type": "string"}},
                             "write": {"type": "array", "items": {"type": "string"}},
                         },
-                        "required": ["event", "read", "write"],
                         "additionalProperties": False,
                     },
                 },
-                "required": ["class", "description", "data_access"],
+                "required": ["class", "description"],
                 "additionalProperties": False,
             },
         },
