@@ -1,3 +1,5 @@
+from pydantic import Field
+
 from canvas_sdk.commands.base import _BaseCommand as BaseCommand
 
 
@@ -6,12 +8,9 @@ class PerformCommand(BaseCommand):
 
     class Meta:
         key = "perform"
-        commit_required_fields = ("cpt_code",)
 
-    cpt_code: str
+    cpt_code: str | None = Field(default=None, json_schema_extra={"commands_api_name": "perform"})
     notes: str | None = None
 
-    @property
-    def values(self) -> dict:
-        """The Perform command's field values."""
-        return {"cpt_code": self.cpt_code, "notes": self.notes}
+
+__exports__ = ("PerformCommand",)
