@@ -11,7 +11,6 @@ class UpdateGoalCommand(_BaseCommand):
 
     class Meta:
         key = "updateGoal"
-        commit_required_fields = ("goal_id",)
 
     class AchievementStatus(Enum):
         IN_PROGRESS = "in-progress"
@@ -37,15 +36,5 @@ class UpdateGoalCommand(_BaseCommand):
     priority: Priority | None = None
     progress: str | None = None
 
-    @property
-    def values(self) -> dict:
-        """The UpdateGoal command's field values."""
-        return {
-            "goal_id": self.goal_id,
-            "due_date": (self.due_date.isoformat() if self.due_date else None),
-            "achievement_status": (
-                self.achievement_status.value if self.achievement_status else None
-            ),
-            "priority": (self.priority.value if self.priority else None),
-            "progress": self.progress,
-        }
+
+__exports__ = ("UpdateGoalCommand",)
