@@ -1,5 +1,7 @@
 from django.db import models
 
+from canvas_sdk.v1.data.base import IdentifiableModel
+
 
 class BusinessLineState(models.TextChoices):
     """BusinessLineStatus."""
@@ -9,21 +11,18 @@ class BusinessLineState(models.TextChoices):
     STATE_ERROR = "error", "Deleted"
 
 
-class BusinessLine(models.Model):
+class BusinessLine(IdentifiableModel):
     """Business Line."""
 
     class Meta:
-        managed = False
         db_table = "canvas_sdk_data_api_businessline_001"
 
-    id = models.UUIDField()
-    dbid = models.BigIntegerField(primary_key=True)
-    name = models.CharField()
+    name = models.CharField(max_length=255)
     description = models.TextField()
-    area_code = models.CharField()
-    subdomain = models.CharField()
+    area_code = models.CharField(max_length=3)
+    subdomain = models.CharField(max_length=100)
     active = models.BooleanField()
-    state = models.CharField(max_length=20, choices=BusinessLineState)
+    state = models.CharField(max_length=20, choices=BusinessLineState.choices)
     organization = models.ForeignKey(
         "v1.Organization", on_delete=models.DO_NOTHING, related_name="business_lines"
     )
