@@ -1,5 +1,6 @@
 from django.db import models
 
+from canvas_sdk.v1.data.base import IdentifiableModel
 from canvas_sdk.v1.data.common import (
     DocumentReviewMode,
     OrderStatus,
@@ -8,17 +9,14 @@ from canvas_sdk.v1.data.common import (
 )
 
 
-class ImagingOrder(models.Model):
+class ImagingOrder(IdentifiableModel):
     """Model to read ImagingOrder data."""
 
     class Meta:
-        managed = False
         db_table = "canvas_sdk_data_api_imagingorder_001"
 
-    id = models.UUIDField()
-    dbid = models.BigIntegerField(primary_key=True)
-    created = models.DateTimeField()
-    modified = models.DateTimeField()
+    created = models.DateTimeField(auto_now_add=True)
+    modified = models.DateTimeField(auto_now=True)
     originator = models.ForeignKey(
         "v1.CanvasUser", on_delete=models.DO_NOTHING, null=True, related_name="+"
     )
@@ -34,30 +32,27 @@ class ImagingOrder(models.Model):
     )
     # TODO - uncomment when Note model is complete
     #  note = models.ForeigneKey(Note, on_delete=models.DO_NOTHING, related_name="imaging_orders", null=True)
-    imaging = models.CharField()
+    imaging = models.CharField(max_length=1024)
     # TODO - uncomment when ServiceProvider model is complete
     # imaging_center = models.ForeignKey('v1.ServiceProvider', on_delete=models.DO_NOTHING, related_name="imaging_orders", null=True)
-    note_to_radiologist = models.CharField()
-    internal_comment = models.CharField()
-    status = models.CharField(choices=OrderStatus)
+    note_to_radiologist = models.CharField(max_length=1024)
+    internal_comment = models.CharField(max_length=1024)
+    status = models.CharField(choices=OrderStatus.choices, max_length=30)
     date_time_ordered = models.DateTimeField()
-    priority = models.CharField()
+    priority = models.CharField(max_length=255)
     # TODO - uncomment when Staff model is complete
     # ordering_provider = models.ForeignKey('v1.Staff', on_delete=models.DO_NOTHING, related_name="imaging_orders", null=True)
     delegated = models.BooleanField(default=False)
 
 
-class ImagingReview(models.Model):
+class ImagingReview(IdentifiableModel):
     """Model to read ImagingReview data."""
 
     class Meta:
-        managed = False
         db_table = "canvas_sdk_data_api_imagingreview_001"
 
-    id = models.UUIDField()
-    dbid = models.BigIntegerField(primary_key=True)
-    created = models.DateTimeField()
-    modified = models.DateTimeField()
+    created = models.DateTimeField(auto_now_add=True)
+    modified = models.DateTimeField(auto_now=True)
     originator = models.ForeignKey(
         "v1.CanvasUser", on_delete=models.DO_NOTHING, null=True, related_name="+"
     )
@@ -68,19 +63,21 @@ class ImagingReview(models.Model):
     entered_in_error = models.ForeignKey(
         "v1.CanvasUser", on_delete=models.DO_NOTHING, null=True, related_name="+"
     )
-    patient_communication_method = models.CharField(choices=ReviewPatientCommunicationMethod)
+    patient_communication_method = models.CharField(
+        choices=ReviewPatientCommunicationMethod.choices, max_length=30
+    )
     # TODO  - uncomment when Note model is complete
     # note = models.ForeignKey('v1.Note', on_delete=models.DO_NOTHING, related_name="imaging_reviews", null=True)
-    internal_comment = models.CharField()
-    message_to_patient = models.CharField()
+    internal_comment = models.CharField(max_length=2048)
+    message_to_patient = models.CharField(max_length=2048)
     is_released_to_patient = models.BooleanField()
-    status = models.CharField(choices=ReviewStatus)
+    status = models.CharField(choices=ReviewStatus.choices, max_length=50)
     patient = models.ForeignKey(
         "v1.Patient", on_delete=models.DO_NOTHING, related_name="imaging_reviews", null=True
     )
 
 
-class ImagingReport(models.Model):
+class ImagingReport(IdentifiableModel):
     """Model to read ImagingReport data."""
 
     class ImagingReportSource(models.TextChoices):
@@ -89,14 +86,11 @@ class ImagingReport(models.Model):
         DIRECTLY_REPORT = "DIRECTLY_RADIOLOGY", "Directly Radiology Report"
 
     class Meta:
-        managed = False
         db_table = "canvas_sdk_data_api_imagingreport_001"
 
-    id = models.UUIDField()
-    dbid = models.BigIntegerField(primary_key=True)
-    created = models.DateTimeField()
-    modified = models.DateTimeField()
-    review_mode = models.CharField(choices=DocumentReviewMode)
+    created = models.DateTimeField(auto_now_add=True)
+    modified = models.DateTimeField(auto_now=True)
+    review_mode = models.CharField(choices=DocumentReviewMode.choices, max_length=2)
     junked = models.BooleanField()
     requires_signature = models.BooleanField()
     assigned_date = models.DateTimeField()
@@ -104,8 +98,8 @@ class ImagingReport(models.Model):
         "v1.Patient", on_delete=models.DO_NOTHING, related_name="imaging_results", null=True
     )
     order = models.ForeignKey(ImagingOrder, on_delete=models.DO_NOTHING, null=True)
-    source = models.CharField(choices=ImagingReportSource)
-    name = models.CharField()
+    source = models.CharField(choices=ImagingReportSource.choices, max_length=18)
+    name = models.CharField(max_length=255)
     result_date = models.DateField()
     original_date = models.DateField()
     review = models.ForeignKey(ImagingReview, on_delete=models.DO_NOTHING, null=True)
