@@ -1,5 +1,7 @@
 from django.db import models
 
+from canvas_sdk.v1.data.base import IdentifiableModel
+
 
 class PostingMethods(models.TextChoices):
     """PostingMethods."""
@@ -10,26 +12,23 @@ class PostingMethods(models.TextChoices):
     OTHER = "other", "Other"
 
 
-class PaymentCollection(models.Model):
+class PaymentCollection(IdentifiableModel):
     """Stores the total collected amount and the payment method."""
 
     class Meta:
-        managed = False
         db_table = "canvas_sdk_data_quality_and_revenue_paymentcollection_001"
 
-    id = models.UUIDField()
-    dbid = models.BigIntegerField(primary_key=True)
     total_collected = models.DecimalField(max_digits=8, decimal_places=2)
-    method = models.CharField(choices=PostingMethods.choices)
+    method = models.CharField(choices=PostingMethods.choices, max_length=10)
 
-    check_number = models.CharField()
+    check_number = models.CharField(max_length=250)
     check_date = models.DateField()
     deposit_date = models.DateField()
 
     description = models.TextField()
 
-    created = models.DateTimeField()
-    modified = models.DateTimeField()
+    created = models.DateTimeField(auto_now_add=True)
+    modified = models.DateTimeField(auto_now=True)
 
 
 __exports__ = ("PaymentCollection", "PostingMethods")
