@@ -1,23 +1,21 @@
 from django.contrib.postgres.fields import ArrayField
 from django.db import models
 
+from canvas_sdk.v1.data.base import IdentifiableModel
 
-class ReasonForVisitSettingCoding(models.Model):
+
+class ReasonForVisitSettingCoding(IdentifiableModel):
     """ReasonForVisitSettingCoding."""
 
     class Meta:
-        managed = False
         db_table = "canvas_sdk_data_api_reasonforvisitsettingcoding_001"
 
     objects: models.Manager["ReasonForVisitSettingCoding"]
 
-    id = models.UUIDField()
-    dbid = models.BigIntegerField(primary_key=True)
-
-    code = models.CharField()
-    display = models.CharField()
-    system = models.CharField()
-    version = models.CharField()
+    code = models.CharField(max_length=255)
+    display = models.CharField(max_length=1000)
+    system = models.CharField(max_length=255)
+    version = models.CharField(max_length=255)
 
     duration = ArrayField(models.DurationField())
 
