@@ -1,3 +1,4 @@
+import uuid
 from collections.abc import Sequence
 from decimal import Decimal
 
@@ -7,4 +8,9 @@ def quantize(deci: Decimal | float | str | tuple[int, Sequence[int], int]) -> De
     return Decimal(deci).quantize(Decimal(".01"))
 
 
+def create_key() -> str:
+    """Generates a unique key using UUID4."""
+    return uuid.uuid4().hex
+
+
 __exports__ = ()
